#!/bin/bash
#
# simple-sync-phone:bin/api/cli/rsync-to-phone-config-api.sh
#
declare -gx PUB_KEY_FILE=

declare -gr WHIPTAIL_TITLE='Simple Sync phone'

declare -gr WHIPTAIL_CHECKLIST_TITLE='Choose public key to use'
declare -gi WHIPTAIL_CHECKLIST_HEIGHT=20
declare -gi WHIPTAIL_CHECKLIST_WIDTH=60
declare -gi WHIPTAIL_CHECKLIST_LISTHEIGHT=5

function __install_if_needed_check__ {
  local -r command="$1"
  local -r package="${2:-${command}}"

  if ! which "${command}" >/dev/null ; then
    echowarn "'${command}' missing, need to install package '${package}'"
    __install_if_needed_packages__+=("${package}")
  else
    echodebug "Command '${command}' found."
  fi
}

function __install_if_needed_finalize__ {
  if [ "${#__install_if_needed_packages__[@]}" -gt 0 ] ; then
    sudo apt install -y "${__install_if_needed_packages__[@]}" || return $?
  else
    echookay 'Nothing to install (ok)'
  fi
}

function __install_if_needed_init__ {
  declare -ga __install_if_needed_packages__=()
}

function requirements_config_init_pub_key_file {
  local -a tis=()
  local -a keyfile=
  while read -r keyfile ; do
    if [ -n "${keyfile}" ] ; then
      tis+=("${keyfile}" '' 'off') # tag item status
    fi
  done <<<"${__REQUIREMENTS_CONFIG_SSH_KEY_FILES__}"

  local whiptail_result=
  local -i whiptail_rc=0
  whiptail_result="$(
    [ "${VERBOSE:-}" = "true" ] && set -x
    whiptail --separate-output \
    --title "${WHIPTAIL_TITLE}" \
    --checklist "${WHIPTAIL_CHECKLIST_TITLE}" \
    "${WHIPTAIL_CHECKLIST_HEIGHT}" "${WHIPTAIL_CHECKLIST_WIDTH}" "${WHIPTAIL_CHECKLIST_LISTHEIGHT}" \
    "${tis[@]}" 3>&1 1>&2 2>&3
  )"
  whiptail_rc=$?

  if [ "${VERBOSE:-}" = "true" ] ; then
    echodebug "whiptail_result='${whiptail_result}'"
    echodebug "whiptail_rc='${whiptail_rc}'"
  fi

  if [ "${whiptail_rc}" -ne 0 ] ; then
    return "${whiptail_rc}"
  fi

  PUB_KEY_FILE="${whiptail_result}"
}

function requirements_config {
  echoinfo 'Verify ssh key on local host'

  if ! __requirements_config_list_ssh_keys__ ; then
    echowarn 'No ssh key found...'

    echoinfo 'Generating a new ssh key.'
    ssh-keygen -a 100 -t ed25519 -C "${USER}@${HOSTNAME}.$( date +'%Y-%m' )" -f "${HOME}/.ssh/id_ed25519" -N '' || return $?

    __requirements_config_list_ssh_keys__ || return $?
  fi

  __requirements_config_list_ssh_key_files__ || return $?

  echoinfo "Found '${__REQUIREMENTS_CONFIG_SSH_KEYS_COUNT__}' key(s)"
  sed -E 's/^(.*)$/-- Public key:\n\1\n--/' <<<"${__REQUIREMENTS_CONFIG_SSH_KEYS__}"
  echoinfo "Found '${__REQUIREMENTS_CONFIG_SSH_KEY_FILES_COUNT__}' public key file(s)"
}
