#!/bin/bash
#
# simple-sync-phone:bin/api/gui/rsync-to-phone-config-api.sh
#
declare -gx PUB_KEY_FILE=

declare -grax KDIALOG_DEFAULT_OPTS=(--title 'simple-sync-phone' --geometry 600x400+100+100)
declare -gr WHIPTAIL_CHECKLIST_TITLE='Choose public key to use'

function __install_if_needed_check__ {
  local -r command="$1"
  local -r package="${2:-${command}}"

  if ! which "${command}" >/dev/null ; then
    echo "'${command}' missing, need to install package '${package}'"
    __install_if_needed_packages__+=("${package}")
  else
    echo "Command '${command}' found."
  fi
}

function __install_if_needed_finalize__ {
  if [ "${#__install_if_needed_packages__[@]}" -gt 0 ] ; then
    sudo apt install -y "${__install_if_needed_packages__[@]}" || return $?
  else
    echo 'Nothing to install (ok)'
  fi
}

function __install_if_needed_init__ {
  declare -ga __install_if_needed_packages__=()
}

function requirements_config_init_pub_key_file {
  local -a tis=()
  local -a keyfile=
  local onoff='on'
  while read -r keyfile ; do
    if [ -n "${keyfile}" ] ; then
      tis+=("${keyfile}" "${keyfile}" "${onoff}") # tag item status
      onoff='off'
    fi
  done <<<"${__REQUIREMENTS_CONFIG_SSH_KEY_FILES__}"

  local __result__=
  local -i __rc__=0
  __result__="$(
    [ "${VERBOSE:-}" = "true" ] && set -x
    kdialog "${KDIALOG_DEFAULT_OPTS[@]}" --separate-output --checklist "${WHIPTAIL_CHECKLIST_TITLE}"  "${tis[@]}"
  )"
  __rc__=$?

  if [ "${VERBOSE:-}" = "true" ] ; then
    echo "${FUNCNAME[0]}() - __result__='${__result__}'"
    echo "${FUNCNAME[0]}() - __rc__='${__rc__}'"
  fi

  if [ "${__rc__}" -ne 0 ] ; then
    return "${__rc__}"
  fi

  PUB_KEY_FILE="${__result__}"
}

function requirements_config {
  echo 'Verify ssh key on local host'

  if ! __requirements_config_list_ssh_keys__ ; then
    echo 'No ssh key found...'
  fi

  __requirements_config_list_ssh_key_files__ || return $?

  echo "Found '${__REQUIREMENTS_CONFIG_SSH_KEYS_COUNT__}' key(s)"
  sed -E 's/^(.*)$/-- Public key:\n\1\n--/' <<<"${__REQUIREMENTS_CONFIG_SSH_KEYS__}"
  echo "Found '${__REQUIREMENTS_CONFIG_SSH_KEY_FILES_COUNT__}' public key file(s)"
}

function requirements_config_fix {
  if [ "${__REQUIREMENTS_CONFIG_SSH_KEY_FILES_COUNT__}" -eq 0 ] ; then

    if kdialog "${KDIALOG_DEFAULT_OPTS[@]}" --warningyesno "Can't find ssh key. Do you want to create a new ssh key?" ; then
      {
        cat <<EOF
simple-sync-phone : Generating a new ssh key.

EOF
        ssh-keygen -a 100 -t ed25519 -C "${USER}@${HOSTNAME}.$( date +'%Y-%m' )" -f "${HOME}/.ssh/id_ed25519" -N '' 2>&1
      } >"${__GUI_OUTPUT__}"

      kdialog "${KDIALOG_DEFAULT_OPTS[@]}" --textbox "${__GUI_OUTPUT__}" # 512 256
    fi

    __requirements_config_list_ssh_keys__ || return $?
    __requirements_config_list_ssh_key_files__ || return $?
  fi

  {
    cat <<EOF
simple-sync-phone :Checkingssh key

Found '${__REQUIREMENTS_CONFIG_SSH_KEYS_COUNT__}' key(s)

EOF

    if [ "${__REQUIREMENTS_CONFIG_SSH_KEYS_COUNT__}" -eq 0 ] ; then
      echo "${__REQUIREMENTS_CONFIG_SSH_KEYS__}"
    else
      sed -E 's/^(.*)$/-- Public key:\n\1\n--/' <<<"${__REQUIREMENTS_CONFIG_SSH_KEYS__}"
    fi
    echo "Found '${__REQUIREMENTS_CONFIG_SSH_KEY_FILES_COUNT__}' public key file(s)"
  } >"${__GUI_OUTPUT__}"

  kdialog "${KDIALOG_DEFAULT_OPTS[@]}" --textbox "${__GUI_OUTPUT__}" # 512 256
}
