#!/bin/bash
#
# simple-sync-phone:bin/api/gui/rsync-to-phone-api.sh
#
function rsync_to_phone_ui {
  local -r ip="$1"
  local -r port="$2"
  local -r copy_into="$3"
  local -r source="$4"
  local -r destination="$5"

  if [ ! -e "${source}" ] ; then
    kdialog --title 'simple-sync-phone' --error "File not found: '${source}'."
    return 100
  fi

  if [ -f "${source}" ] ; then
    local -i lines_count=5 # 1 * 2 + 3

    echo "Synchronize file: '${source}'" # Trace only
  elif [ -d "${source}" ] ; then
    local -i entries_count=0
    entries_count="$( find "${source}" -mindepth 1 | wc -l  )"

    local -i lines_count=$(( entries_count * 2 + 3 ))

    if [ "${copy_into}" = 'false' ] ; then
      lines_count=$(( lines_count+ 1 ))
    fi

    echo "Synchronize directory: '${source}' (${lines_count})" # Trace only
  else
    kdialog --title 'simple-sync-phone' --error "Can't handle: '${source}'"
    return 100
  fi

  local kref=
  kref=" $(kdialog "${KDIALOG_DEFAULT_OPTS[@]}" --progressbar "Initializing rsync . . ." 10 )"

  # shellcheck disable=SC2086 # Double quote to prevent globbing and word splitting.
  qdbus ${kref} org.freedesktop.DBus.Properties.Set org.kde.kdialog.ProgressDialog maximum "${lines_count}"
# qdbus ${kref} org.freedesktop.DBus.Properties.Set org.kde.kdialog.ProgressDialog.showCancelButton false
# qdbus ${kref} org.freedesktop.DBus.Properties.Set org.kde.kdialog.ProgressDialog.ignoreCancel

  local -i count=0
  rsync_to_phone "${ip}" "${port}" "${copy_into}" "${source}" "${destination}" |
    grep '^[^[:blank:]]' |
    while read -r line ; do
      count=$(( count+ 1 ))

      # shellcheck disable=SC2086 # Double quote to prevent globbing and word splitting.
      qdbus ${kref} org.freedesktop.DBus.Properties.Set org.kde.kdialog.ProgressDialog value "${count}"
      # shellcheck disable=SC2086 # Double quote to prevent globbing and word splitting.
      qdbus ${kref} org.kde.kdialog.ProgressDialog.setLabelText "${line}"
    done

  sleep 1
  # shellcheck disable=SC2086 # Double quote to prevent globbing and word splitting.
  qdbus ${kref} org.kde.kdialog.ProgressDialog.close
}
