#!/bin/bash
#
# simple-sync-phone:bin/api/rsync-to-phone-api.sh
#
declare -gx RSYNC_TO_PHONE_REMOTE_USER='user'

function rsync_to_phone {
  local -r ip="$1"
  local -ri port="$2"
  local -r copy_into="$3"
  local -r source="$4"
  local -r destination="$5"

  local -a rsync_opts=()
  rsync_opts+=('--compress')
  rsync_opts+=('--copy-links')
  rsync_opts+=('--progress')
  rsync_opts+=('--update')
  rsync_opts+=('--verbose')

  local fixed_source=
  local fixed_destination=
  case "${copy_into}" in
    'true')
      if [ -d "${source}" ] ; then
        fixed_source='.'
        fixed_destination="$( dirname "${destination}" )/$( basename "${destination}" )/"
      else
        echo "${FUNCNAME[0]}() - Wrong value for copy_into='${copy_into}' or source=$'{source}' (not an existing directory)"
      fi
      ;;

    'false')
      fixed_source="${source}"
      fixed_destination="${destination}"
      ;;

    *)
      echo "${FUNCNAME[0]}() - Wrong value for copy_into='${copy_into}' (must be 'true' or 'false')"
      return 100
      ;;
  esac

  if [ -d "${source}" ] ; then
    rsync_opts+=('--delete')
    rsync_opts+=('--recursive')
  elif [ ! -f "${source}" ] ; then
    echo "${FUNCNAME[0]}() - Can't handle: '${source}'"
    return 100
  fi

  (
    [ "${VERBOSE:-}" = "true" ] && set -x
    if [ "${fixed_source}" = '.' ] ; then
      cd "${source}" || return $?
    fi
    rsync "${rsync_opts[@]}" -e "ssh -p '${port}'" "${fixed_source}" "${RSYNC_TO_PHONE_REMOTE_USER}@${ip}:${fixed_destination}"
  ) || return $?
}

